<?php
// $con = mysqli_connect("localhost", "xtodo", "_1x-v0Xv(^qu4$s+", "xtodo_pipscart");
$con = mysqli_connect("localhost","xtodo_safiya","n#o})TqFR*5laI6~","xtodo_pipscart");
if (!$con) {
    die("Connection failed: " . mysqli_connect_error());
}

?>