<!DOCTYPE html>
<html lang="en">
   <head>
      <!-- Required meta tags -->
      <meta charset="utf-8">
      <meta name="viewport" content="width=device-width, initial-scale=1, shrink-to-fit=no">
      <title>Pipscart</title>
      <!-- plugins:css -->
      <link rel="stylesheet" href="assets/vendors/mdi/css/materialdesignicons.min.css">
      <link rel="stylesheet" href="assets/vendors/ti-icons/css/themify-icons.css">
      <link rel="stylesheet" href="assets/vendors/css/vendor.bundle.base.css">
      <link rel="stylesheet" href="assets/vendors/font-awesome/css/font-awesome.min.css">
      <!-- endinject -->
      <!-- Plugin css for this page -->
      <link rel="stylesheet" href="assets/vendors/font-awesome/css/font-awesome.min.css" />
      <link rel="stylesheet" href="assets/vendors/bootstrap-datepicker/bootstrap-datepicker.min.css">
      <!-- End plugin css for this page -->
      <!-- inject:css -->
      <!-- endinject -->
      <!-- Layout styles -->
      <link rel="stylesheet" href="assets/css/style.css">
      <!-- End layout styles -->
      <!-- <link rel="shortcut icon" href="assets/images/favicon.png" /> -->
   </head>
   <body>
      <div class="container-scroller">
         <!-- partial:partials/_navbar.html -->
         <!-- partial:partials/_navbar.html -->
         <?php
            $title = "Php Header Footer";
            include "header.php";
            ?>
         <!-- partial -->
         <div class="container-fluid page-body-wrapper">
            <!-- partial:partials/_sidebar.html -->
            <?php
               $title = "Php Header Footer";
               include "sidebar.php";
               ?>
            <!-- partial -->
            <!-- partial -->
            <div class="main-panel">
               <div class="content-wrapper">
                  <!-- <div class="page-header">
                     <h3 class="page-title">
                       <span class="page-title-icon bg-gradient-primary text-white me-2">
                         <i class="mdi mdi-home"></i>
                       </span> Dashboard
                     </h3>
                     <nav aria-label="breadcrumb">
                       <ul class="breadcrumb">
                         <li class="breadcrumb-item active" aria-current="page">
                           <span></span>Overview <i class="mdi mdi-alert-circle-outline icon-sm text-primary align-middle"></i>
                         </li>
                       </ul>
                     </nav>
                     </div> -->
                  <div class="row">
                     <div class="col-md-12">
                        <div class="card">
                           <div class="card-body">
                              <h4 class="card-title">Customer Register</h4>
                              <div class="row">
                                <div class="col-md-4">
                              <form class="forms-sample">
                                 <!-- <div class="form-group">
                                    <input type="text" class="form-control" id="exampleInputUsername1" placeholder="Item Code">
                                    </div> -->
                                 <div class="form-group">
                                    <select name="category" id="edit_category" class="form-select" required="">
                                       <option selected="" disabled="">Select Branch</option>
                                       <option value="1">test</option>
                                       <option value="3">test1</option>
                                       <option value="2">test2</option>
                                    </select>
                                 </div>
                                 <button type="submit" class="btn btn-gradient-primary w-100">Submit</button>
                              </form>  </div>
                              </div>
                           </div>
                        </div>
                     </div>
                  </div>
                  <div class="col-md-8"></div>
               </div>
               <!-- content-wrapper ends -->
               <!-- partial:partials/_footer.html -->
               <?php
                  $title = "Php Header Footer";
                  include "footer.php";
                  ?>
               <!-- partial -->
            </div>
            <!-- main-panel ends -->
         </div>
         <!-- page-body-wrapper ends -->
      </div>
      <style>
         .hover-preview-container {
         position: relative;
         display: inline-block;
         }
         .table th img, .table td img {
         width: 36px;
         height: 36px;
         border-radius: 0!important;
         }
         .hover-image {
         display: none;
         position: absolute;
         bottom: 100%; /* puts image above the link */
         left: 0;
         margin-bottom: 10px;
         width: 200px;
         border: 1px solid #ccc;
         background: #fff;
         box-shadow: 0 0 10px rgba(0,0,0,0.2);
         z-index: 1000;
         }
         .hover-preview-container:hover .hover-image {
         display: block;
         }
      </style>
      <!-- container-scroller -->
      <!-- plugins:js -->
      <script src="assets/vendors/js/vendor.bundle.base.js"></script>
      <!-- endinject -->
      <!-- Plugin js for this page -->
      <script src="assets/vendors/chart.js/chart.umd.js"></script>
      <script src="assets/vendors/bootstrap-datepicker/bootstrap-datepicker.min.js"></script>
      <!-- End plugin js for this page -->
      <!-- inject:js -->
      <script src="assets/js/off-canvas.js"></script>
      <script src="assets/js/misc.js"></script>
      <script src="assets/js/settings.js"></script>
      <script src="assets/js/todolist.js"></script>
      <script src="assets/js/jquery.cookie.js"></script>
      <!-- endinject -->
      <!-- Custom js for this page -->
      <script src="assets/js/dashboard.js"></script>
      <!-- End custom js for this page -->
   </body>
</html>