<footer class="footer">
            <div class="d-sm-flex justify-content-center justify-content-sm-between">
              <span class="text-muted text-center text-sm-left d-block d-sm-inline-block">Copyright © <span id="year"></span> <a href="https://www.bootstrapdash.com/" target="_blank"></a>. All rights reserved.</span>
              <span class="float-none float-sm-right d-block mt-1 mt-sm-0 text-center">Developed by <a href="www.programers.in" target="_blank">Programers.in</a></span>
            </div>
          </footer>
<script>
        document.addEventListener("DOMContentLoaded", function () {
            // Get the current file name without extension
            let fileName = window.location.pathname.split("/").pop().split(".")[0];
            // Capitalize first letter
            fileName = fileName.charAt(0).toUpperCase() + fileName.slice(1);
            // Set it as the page title
            document.title = fileName;
        });
    </script>
          <script>
    document.getElementById("year").textContent = new Date().getFullYear();
</script>