
            <?php
            error_reporting(0);
               session_start();
               if(!isset($_SESSION['user_id']) || !isset($_SESSION['username'])){
    header("Location: index.php");
    exit();
}
                $userid = $_SESSION['user_id'] ;
                $username = $_SESSION['username'] ;
            ?>
         <nav class="navbar default-layout-navbar col-lg-12 col-12 p-0 fixed-top d-flex flex-row">
             
             <?php
                if ($username == 'admin') {
                ?>
                    <div class="text-center navbar-brand-wrapper d-flex align-items-center justify-content-start">
                        <a class="navbar-brand brand-logo" href="dashboard"><img src="assets/images/logo.svg" alt="logo" /></a>
                        <a class="navbar-brand brand-logo-mini" href="dashboard"><img src="assets/images/logo-mini.svg" alt="logo" /></a>
                    </div>
                <?php
                } else {
                ?>
                    <div class="text-center navbar-brand-wrapper d-flex align-items-center justify-content-start">
                        <a class="navbar-brand brand-logo" href="staff-dashboard"><img src="assets/images/logo.svg" alt="logo" /></a>
                        <a class="navbar-brand brand-logo-mini" href="staff-dashboard"><img src="assets/images/logo-mini.svg" alt="logo" /></a>
                    </div>
                <?php
                }
                ?>

   
            
            
            <div class="navbar-menu-wrapper d-flex align-items-stretch">
               <button class="navbar-toggler navbar-toggler align-self-center" type="button" data-toggle="minimize">
               <span class="mdi mdi-menu"></span>
               </button>
               <div class="search-field d-none d-md-block">
          
               </div>
               <ul class="navbar-nav navbar-nav-right">
                  <li class="nav-item d-none d-lg-block full-screen-link">
                     <a class="nav-link">
                     <i class="mdi mdi-fullscreen" id="fullscreen-button"></i>
                     </a>
                  </li>

                  <li class="nav-item nav-logout d-none d-lg-block">
                     <a class="nav-link" href="logout.php">
                     <i class="mdi mdi-power"></i>
                     </a>
                  </li>
                  
                  <li class="nav-item nav-profile dropdown">
                     <a class="nav-link dropdown-toggle" id="profileDropdown" href="#" data-bs-toggle="dropdown" aria-expanded="false">
                        <div class="nav-profile-img">
                           <img src="uploads/profile_default.png" alt="image">
                           <span class="availability-status online"></span>
                        </div>
                        <div class="nav-profile-text">
                           <p class="mb-1 text-black"><?php echo $username; ?></p>
                        </div>
                     </a>
                     <div class="dropdown-menu navbar-dropdown" aria-labelledby="profileDropdown">
                        <!-- <a class="dropdown-item" href="#">
                        <i class="mdi mdi-cached me-2 text-success"></i> Activity Log </a>
                        <div class="dropdown-divider"></div> -->
                        <a class="dropdown-item" href="logout.php">
                        <i class="mdi mdi-logout me-2 text-primary"></i> Signout </a>
                     </div>
                  </li>
               </ul>
               <button class="navbar-toggler navbar-toggler-right d-lg-none align-self-center" type="button" data-toggle="offcanvas">
               <span class="mdi mdi-menu"></span>
               </button>
            </div>
         </nav>